# hermes

A simple python-based group chat server built on XMPP. Hermes lets you easily manage chatrooms for friends or colleagues.

## How it Works

Supply your own XMPP-based (e.g. GMail/Google Talk) accounts to serve as chatroom hosts, add a lil' bit of configuration, and start it. Chatroom members simply chat with the host account. Hermes broadcasts the message to all other members on its behalf.

## Usage

TODO

## Installation

Package available from PyPI: <http://pypi.python.org/pypi/hermes/>. Install with:

    pip install hermes
    
## Is it any good?

Yes.
